# lvm_tools

Lightweight wrapper of [LVM DRP](https://github.com/sdss/lvmdrp) data with an emphasis on modularity. Allows for lazy reading via [`dask`](https://www.dask.org), especially useful for fitting large models. Designed for use with spectrospatial models via [`spectracles`](https://github.com/TomHilder/spectracles) but probably useful for other things too.

Feel free to contact me personally if you have any questions at all.

## Installation

TODO

## Usage

TODO

## Citation

TODO

## Help

TODO

## TODO

- [ ] repr for FitData
- [ ] Logging/hashing
- [ ] Cache
- [ ] OptConfig
